Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src\pqlattice\__init__.py | 4 | 0 | 0 | 100%
src\pqlattice\_utils.py | 9 | 0 | 0 | 100%
src\pqlattice\integer\__init__.py | 5 | 0 | 0 | 100%
src\pqlattice\integer\_integer.py | 24 | 1 | 8 | 96%
src\pqlattice\integer\_modintring.py | 33 | 2 | 36 | 94%
src\pqlattice\integer\_modring.py | 26 | 0 | 40 | 100%
src\pqlattice\integer\_primality.py | 44 | 8 | 0 | 82%
src\pqlattice\integer\_primes.py | 1 | 0 | 0 | 100%
src\pqlattice\lattice\__init__.py | 9 | 0 | 0 | 100%
src\pqlattice\lattice\_bkz.py | 48 | 1 | 0 | 98%
src\pqlattice\lattice\_cvp.py | 24 | 11 | 0 | 54%
src\pqlattice\lattice\_embeddings.py | 19 | 6 | 0 | 68%
src\pqlattice\lattice\_gso.py | 20 | 0 | 0 | 100%
src\pqlattice\lattice\_hkz.py | 6 | 0 | 0 | 100%
src\pqlattice\lattice\_lattice.py | 42 | 2 | 0 | 95%
src\pqlattice\lattice\_lll.py | 41 | 8 | 0 | 80%
src\pqlattice\lattice\_svp.py | 58 | 0 | 0 | 100%
src\pqlattice\lattice\embeddings.py | 2 | 0 | 0 | 100%
src\pqlattice\linalg\__init__.py | 4 | 0 | 0 | 100%
src\pqlattice\linalg\_linalg.py | 90 | 8 | 0 | 91%
src\pqlattice\linalg\_modint.py | 76 | 57 | 0 | 25%
src\pqlattice\linalg\_utils.py | 28 | 1 | 0 | 96%
src\pqlattice\polynomial\__init__.py | 4 | 0 | 0 | 100%
src\pqlattice\polynomial\_modpolyqring.py | 46 | 12 | 0 | 74%
src\pqlattice\polynomial\_modpolyring.py | 66 | 26 | 0 | 61%
src\pqlattice\polynomial\_poly.py | 58 | 13 | 0 | 78%
src\pqlattice\polynomial\poly.py | 2 | 0 | 0 | 100%
src\pqlattice\random\__init__.py | 6 | 0 | 0 | 100%
src\pqlattice\random\_distribution.py | 93 | 32 | 0 | 66%
src\pqlattice\random\_lattice.py | 3 | 1 | 0 | 67%
src\pqlattice\random\_lwe.py | 7 | 2 | 6 | 71%
src\pqlattice\random\_lwr.py | 7 | 2 | 6 | 71%
src\pqlattice\random\_prime.py | 28 | 1 | 0 | 96%
src\pqlattice\random\distribution.py | 2 | 0 | 0 | 100%
src\pqlattice\typing\__init__.py | 3 | 0 | 0 | 100%
src\pqlattice\typing\_types.py | 6 | 0 | 0 | 100%
src\pqlattice\typing\_types_validator.py | 36 | 0 | 0 | 100%
Total | 980 | 194 | 96 | 80%

No items found using the specified filter.